@@ -3,6 +3,7 @@
 
 import argparse
 import os
+import sys
 import pandas
 import sqlite3
 
@@ -10,9 +11,14 @@ def csvjoin_main():
     parser = argparse.ArgumentParser()
     parser.add_argument( "-d", "--csv", "--data", dest="csv", action="append", help="specify csv files. '[alias=]csvfile'")
     parser.add_argument( "-q", "--sql", "--query",dest="sql", default=None,  help="SQL")
+    parser.add_argument( "-J", "--json", dest="json", action="store_true", default=False, help="dump result in JSON",)
     parser.add_argument( "-X", "--debug", dest="debug", action="store_true", default=False, help="debug mode",)
     args = parser.parse_args()
     
+    if not (args.csv and args.sql ) :
+        print("# must specify csv files(-d) and sql(-q).",file=sys.stderr,flush=True)
+        sys.exit(-1)
+
     con = sqlite3.connect(":memory:")
 
     for csvfile in args.csv :
@@ -28,7 +34,10 @@ def csvjoin_main():
     pandas.options.display.width = 0
 
     df = pandas.read_sql_query(args.sql, con)
-    print(df)
+    if args.json :
+        print(df.to_json(orient="records"))
+    else :
+        print(df)
 
 
 if __name__ == "__main__":
